==> connector-framework-1.4.0.0-sources.jar: org/identityconnectors/framework/common/objects/filter/ExternallyChainedFilter.java <==
/*
 * ====================
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008-2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Common Development
 * and Distribution License("CDDL") (the "License").  You may not use this file
 * except in compliance with the License.
 *
 * You can obtain a copy of the License at
 * http://opensource.org/licenses/cddl1.php
 * See the License for the specific language governing permissions and limitations
 * under the License.
 *
 * When distributing the Covered Code, include this CDDL Header Notice in each file
 * and include the License file at http://opensource.org/licenses/cddl1.php.
 * If applicable, add the following below this CDDL Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * ====================
 * Portions Copyrighted 2013 Evolveum
 */
package org.identityconnectors.framework.common.objects.filter;

/**
 *
 * Externally chained filters e.g. the filter implementing case insensitive searches.
 * They are removed from translation.
 *
 * IMPORTANT: Currently, these filters have to be chained at the beginning of the filter tree.
 *
 * @author mederly
 */
public abstract class ExternallyChainedFilter implements Filter {

    private Filter filter;

    public ExternallyChainedFilter(Filter filter) {
        this.filter = filter;
    }

    public Filter getFilter() {
        return filter;
    }
}

==> connector-framework-1.5.2.0-sources.jar: org/identityconnectors/framework/common/objects/filter/ExternallyChainedFilter.java <==
/*
 * ====================
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright 2008-2009 Sun Microsystems, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Common Development
 * and Distribution License("CDDL") (the "License").  You may not use this file
 * except in compliance with the License.
 *
 * You can obtain a copy of the License at
 * http://opensource.org/licenses/cddl1.php
 * See the License for the specific language governing permissions and limitations
 * under the License.
 *
 * When distributing the Covered Code, include this CDDL Header Notice in each file
 * and include the License file at http://opensource.org/licenses/cddl1.php.
 * If applicable, add the following below this CDDL Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyrighted [year] [name of copyright owner]"
 * ====================
 * Portions Copyrighted 2013 Evolveum
 */
package org.identityconnectors.framework.common.objects.filter;

/**
 *
 * Externally chained filters e.g. the filter implementing case insensitive searches.
 * They are removed from translation.
 *
 * IMPORTANT: Currently, these filters have to be chained at the beginning of the filter tree.
 *
 * @author mederly
 */
public abstract class ExternallyChainedFilter implements Filter {

    private final Filter filter;

    public ExternallyChainedFilter(Filter filter) {
        this.filter = filter;
    }

    public Filter getFilter() {
        return filter;
    }
}
